const gulp = require('gulp');
const rename = require('gulp-rename');
const eslint = require('gulp-eslint');
const babel = require('gulp-babel');
const mocha = require('gulp-mocha');
const browserify = require('gulp-browserify');
const babelCore = require('babel-core/register');

gulp.task('eslint', () => {
    return gulp.src(['./src/**/*.js'])
        .pipe(eslint())
        .pipe(eslint.format())
        .pipe(eslint.failAfterError())
    ;
});

gulp.task('test-unit', ['eslint'], () => {
    return gulp.src('./test/unit/**/*.js')
        .pipe(mocha({
            js: babelCore,
            reporter: 'min'
        }))
        .on('error', () => {
            gulp.emit('end');
        });
});

gulp.task('test-integration', ['test-unit'], () => {
    return gulp.src('./test/integration/**/*.js')
        .pipe(mocha({
            js: babelCore,
            reporter: 'min'
        }))
        .on('error', () => {
            gulp.emit('end');
        });
});

gulp.task('transpile', ['test-unit'], () => {
    return gulp.src('./src/**/**/*.js')
        .pipe(babel())
        .pipe(gulp.dest('./lib'));
});

gulp.task('browserify', ['transpile'], () => {
    return gulp.src('./lib/index.js')
        .pipe(browserify())
        .pipe(rename('do-translate.js'))
        .pipe(gulp.dest('./lib'))
    ;
});

gulp.task('default', ['transpile'], () => {
});

